# Generated by Django 3.1.4 on 2020-12-29 17:20

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import unchained_utils.v0.base_classes
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Notification',
            fields=[
                ('id', models.CharField(default=uuid.uuid4, editable=False, max_length=36, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True, db_index=True)),
                ('updated_at', models.DateTimeField(auto_now=True, db_index=True)),
                ('text', models.CharField(max_length=200)),
                ('title', models.CharField(max_length=200)),
                ('type', models.CharField(max_length=50)),
                ('payload', models.TextField(blank=True, null=True)),
                ('user', unchained_utils.v0.base_classes.LooseForeignKey(blank=True, db_constraint=False, on_delete=django.db.models.deletion.DO_NOTHING, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'get_latest_by': 'created_at',
                'abstract': False,
            },
        ),
    ]
